// src/react/BasicElementsPlugin.ts
import { createPlatePlugin } from "@udecode/plate/react";

// src/react/BlockquotePlugin.tsx
import { toPlatePlugin } from "@udecode/plate/react";

// src/lib/BaseBlockquotePlugin.ts
import { createSlatePlugin, KEYS } from "@udecode/plate";
var BaseBlockquotePlugin = createSlatePlugin({
  key: KEYS.blockquote,
  node: { isElement: true },
  parsers: {
    html: {
      deserializer: {
        rules: [
          {
            validNodeName: "BLOCKQUOTE"
          }
        ]
      }
    }
  },
  render: { as: "blockquote" }
});

// src/react/BlockquotePlugin.tsx
var BlockquotePlugin = toPlatePlugin(BaseBlockquotePlugin);

// src/react/HeadingPlugin.tsx
import { toPlatePlugin as toPlatePlugin2 } from "@udecode/plate/react";

// src/lib/BaseHeadingPlugin.ts
import {
  createTSlatePlugin
} from "@udecode/plate";
var BaseH1Plugin = createTSlatePlugin({
  key: "h1",
  node: { isElement: true },
  parsers: { html: { deserializer: { rules: [{ validNodeName: "H1" }] } } },
  render: { as: "h1" }
}).extendTransforms(({ editor, type }) => ({
  toggle: () => {
    editor.tf.toggleBlock(type);
  }
}));
var BaseH2Plugin = createTSlatePlugin({
  key: "h2",
  node: { isElement: true },
  parsers: { html: { deserializer: { rules: [{ validNodeName: "H2" }] } } },
  render: { as: "h2" }
}).extendTransforms(({ editor, type }) => ({
  toggle: () => {
    editor.tf.toggleBlock(type);
  }
}));
var BaseH3Plugin = createTSlatePlugin({
  key: "h3",
  node: { isElement: true },
  parsers: { html: { deserializer: { rules: [{ validNodeName: "H3" }] } } },
  render: { as: "h3" }
}).extendTransforms(({ editor, type }) => ({
  toggle: () => {
    editor.tf.toggleBlock(type);
  }
}));
var BaseH4Plugin = createTSlatePlugin({
  key: "h4",
  node: { isElement: true },
  parsers: { html: { deserializer: { rules: [{ validNodeName: "H4" }] } } },
  render: { as: "h4" }
}).extendTransforms(({ editor, type }) => ({
  toggle: () => {
    editor.tf.toggleBlock(type);
  }
}));
var BaseH5Plugin = createTSlatePlugin({
  key: "h5",
  node: { isElement: true },
  parsers: { html: { deserializer: { rules: [{ validNodeName: "H5" }] } } },
  render: { as: "h5" }
}).extendTransforms(({ editor, type }) => ({
  toggle: () => {
    editor.tf.toggleBlock(type);
  }
}));
var BaseH6Plugin = createTSlatePlugin({
  key: "h6",
  node: { isElement: true },
  parsers: { html: { deserializer: { rules: [{ validNodeName: "H6" }] } } },
  render: { as: "h6" }
}).extendTransforms(({ editor, type }) => ({
  toggle: () => {
    editor.tf.toggleBlock(type);
  }
}));
var BaseHeadingPlugin = createTSlatePlugin({
  key: "heading",
  options: {
    levels: [1, 2, 3, 4, 5, 6]
  }
}).extend(({ plugin }) => {
  const {
    options: { levels }
  } = plugin;
  const headingPlugins = {
    1: BaseH1Plugin,
    2: BaseH2Plugin,
    3: BaseH3Plugin,
    4: BaseH4Plugin,
    5: BaseH5Plugin,
    6: BaseH6Plugin
  };
  const headingLevels = Array.isArray(levels) ? levels : Array.from({ length: levels || 6 }, (_, i) => i + 1);
  const plugins = headingLevels.map(
    (level) => headingPlugins[level]
  );
  return { plugins };
});

// src/react/HeadingPlugin.tsx
var HeadingPlugin = toPlatePlugin2(BaseHeadingPlugin);
var H1Plugin = toPlatePlugin2(BaseH1Plugin);
var H2Plugin = toPlatePlugin2(BaseH2Plugin);
var H3Plugin = toPlatePlugin2(BaseH3Plugin);
var H4Plugin = toPlatePlugin2(BaseH4Plugin);
var H5Plugin = toPlatePlugin2(BaseH5Plugin);
var H6Plugin = toPlatePlugin2(BaseH6Plugin);

// src/react/HorizontalRulePlugin.tsx
import { toPlatePlugin as toPlatePlugin3 } from "@udecode/plate/react";

// src/lib/BaseHorizontalRulePlugin.ts
import { createSlatePlugin as createSlatePlugin2, KEYS as KEYS2 } from "@udecode/plate";
var BaseHorizontalRulePlugin = createSlatePlugin2({
  key: KEYS2.hr,
  node: { isElement: true, isVoid: true },
  parsers: {
    html: {
      deserializer: {
        rules: [
          {
            validNodeName: "HR"
          }
        ]
      }
    }
  },
  render: { as: "hr" }
});

// src/react/HorizontalRulePlugin.tsx
var HorizontalRulePlugin = toPlatePlugin3(BaseHorizontalRulePlugin);

// src/react/BasicElementsPlugin.ts
var BasicElementsPlugin = createPlatePlugin({
  plugins: [BlockquotePlugin, HeadingPlugin, HorizontalRulePlugin]
});
export {
  BasicElementsPlugin,
  BlockquotePlugin,
  H1Plugin,
  H2Plugin,
  H3Plugin,
  H4Plugin,
  H5Plugin,
  H6Plugin,
  HeadingPlugin,
  HorizontalRulePlugin
};
//# sourceMappingURL=index.mjs.map